@@ -4,6 +4,8 @@
 import re
 import datetime
 from pathlib import Path
+from palp.exception.exception_error import SpiderHasExistsError
+from palp.tool.short_module import find_spiders_path, find_spiders_class
 
 
 class CreateSpider:
@@ -13,6 +15,10 @@ class CreateSpider:
         :param spider_name: spider 名字
         :param spider_type: spider 类型（1 为普通 spider，2 为分布式 spider）
         """
+        self.spider_exists = find_spiders_class()
+        if spider_name.lower() in self.spider_exists:
+            raise SpiderHasExistsError(f'{spider_name} 已存在！')
+
         self.spider_name = spider_name
         self.spider_type = spider_type
         self.path = Path('.').absolute()  # 相对路径
@@ -37,7 +43,7 @@ class CreateSpider:
         content = content.replace('${SPIDER_NAME_LOWER}', self.spider_name.lower())
         content = content.replace('${DATE}', str(datetime.datetime.now()))
 
-        spider_dir = self.find_path(path=self.path)
+        spider_dir = find_spiders_path(path=self.path)
         if not spider_dir:
             spider_dir = self.path
 
@@ -57,22 +63,6 @@ class CreateSpider:
 
         raise NameError('Spider 名字请以字母开头，并仅含有数字字母下划线！')
 
-    def find_path(self, path: Path) -> Path:
-        """
-        寻找 spiders 文件夹的位置
-
-        :param path:
-        :return:
-        """
-        if path.is_dir() and path.name == 'spiders':
-            return path
-
-        for spider_dir in path.iterdir():
-            if spider_dir.is_dir():
-                spider_dir = self.find_path(spider_dir)
-                if spider_dir:
-                    return spider_dir
-
 
 if __name__ == '__main__':
     CreateSpider(spider_name='demo', spider_type=1).create()
